@@ -24,7 +24,7 @@
     limitations under the License.
 """
 
-import os
+import os.path
 
 
 def icons(name, origin=u"tango"):
